@@ -1732,6 +1732,8 @@ class RecipeTestCase(unittest.TestCase):
         deggs = os.path.join(sample, "develop-eggs")
         os.mkdir(deggs)
 
+        zc.buildout.testing.install_develop("setuptools", deggs)
+        zc.buildout.testing.install_develop("zc.buildout", deggs)
         zc.buildout.testing.install_develop("pwt.jinja2js", deggs)
         zc.buildout.testing.install_develop("pwt.recipe.closurebuilder", deggs)
         zc.buildout.testing.install_develop("WebOb", deggs)
@@ -1765,6 +1767,7 @@ extension = soy
             # in the eggs dir.
             ("buildout", "develop-eggs-directory", "eggs"),
             ("buildout", "offline", "true"),
+            ("buildout", "newest", "false"),
             ]
         zc.buildout.buildout.Buildout(
             "buildout.cfg", config, user_defaults=False,
